@@ -97,79 +97,6 @@ pub fn fetch_problem(problem_name: &str, problem_dir: &Path) -> MapmResult<Probl
 }
 
 impl Problem {
-    /// Converts Problem into TeX string to be inputted in `mapm-headers.tex`
-    ///
-    /// # Usage
-    ///
-    /// ```
-    /// use mapm::problem::Problem;
-    /// use std::collections::HashMap;
-    ///
-    /// let mut vars = HashMap::new();
-    /// vars.insert(String::from("problem"), String::from("What is $1+1$?"));
-    /// vars.insert(String::from("author"), String::from("Dennis Chen"));
-    ///
-    /// let mut solution_one = HashMap::new();
-    /// solution_one.insert(String::from("text"), String::from("It's probably $2$."));
-    /// solution_one.insert(String::from("author"), String::from("Dennis Chen"));
-    /// let mut solution_two = HashMap::new();
-    /// solution_two.insert(String::from("text"), String::from("The answer is $2$, but my proof is too small to fit into the margin."));
-    /// solution_two.insert(String::from("author"), String::from("Pierre de Fermat"));
-    ///
-    /// let mut solutions = Vec::from([solution_one, solution_two]);
-    ///
-    /// let problem = Problem { vars, solutions };
-    ///
-    /// println!("{}", problem.as_tex(1));
-    /// ```
-    pub fn as_tex(&self, problem_number: u32) -> String {
-        let mut tex: String = String::new();
-        for (key, val) in &self.vars {
-            tex.push_str(
-                &[
-                    "\\expandafter\\def\\csname mapm@probvar@",
-                    &problem_number.to_string(),
-                    "@",
-                    &key,
-                    "\\endcsname{",
-                    &val,
-                    "}\n",
-                ]
-                .concat(),
-            );
-        }
-        tex.push_str(
-            &[
-                "\\expandafter\\def\\csname mapm@solcount@",
-                &problem_number.to_string(),
-                "\\endcsname{",
-                &self.solutions.len().to_string(),
-                "}",
-            ]
-            .concat(),
-        );
-        for (pos, map) in self.solutions.iter().enumerate() {
-            for (key, val) in map {
-                let solution_number = (&pos + 1).to_string();
-                tex.push_str(
-                    &[
-                        "\\expandafter\\def\\csname mapm@solvar@",
-                        &problem_number.to_string(),
-                        "@",
-                        &solution_number,
-                        "@",
-                        &key,
-                        "\\endcsname{",
-                        &val,
-                        "}\n",
-                    ]
-                    .concat(),
-                );
-            }
-        }
-        return tex;
-    }
-
     /// Checks if a problem passes or fails a certain filter
     ///
     /// For Gt, it checks if the value of the problem is greater than the value passed in the filter (not the other way around). The same is true of Lt, Ge, Le.
